diff --git a/GUI/Model/Detector/DetectorItem.cpp b/GUI/Model/Detector/DetectorItem.cpp
index fcc6870b8201d5f8548a58b80210eff021f98613..488c723cdbba373c11d6790c1c2726d68d175245 100644
--- a/GUI/Model/Detector/DetectorItem.cpp
+++ b/GUI/Model/Detector/DetectorItem.cpp
@@ -44,7 +44,7 @@ DetectorItem::DetectorItem()
     , m_prjns(std::make_unique<MasksSet>())
 {
     m_resolution_function.initWithArgs("Resolution function", "Detector resolution function",
-                                       ResolutionFunctionItemCatalog::Type::None);
+                                       ResolutionFunctionCatalog::Type::None);
 }
 
 DetectorItem::~DetectorItem() = default;
diff --git a/GUI/Model/Detector/DetectorItem.h b/GUI/Model/Detector/DetectorItem.h
index 64093c0ddb876bd3634456b7fad03f8d6c2a86cb..e6be67466d13cb5a931be5f31e955847938997f7 100644
--- a/GUI/Model/Detector/DetectorItem.h
+++ b/GUI/Model/Detector/DetectorItem.h
@@ -17,7 +17,7 @@
 
 #include "GUI/Model/Descriptor/AxisProperty.h"
 #include "GUI/Model/Descriptor/PolyItem.h"
-#include "GUI/Model/Detector/ResolutionFunctionItemCatalog.h"
+#include "GUI/Model/Detector/ResolutionFunctionCatalog.h"
 
 class IDetector;
 class IResolutionFunction2D;
@@ -33,7 +33,7 @@ public:
 
     void setMasks(MasksSet* item);
 
-    PolyItem<ResolutionFunctionItemCatalog>& resolutionFunctionSelection()
+    PolyItem<ResolutionFunctionCatalog>& resolutionFunctionSelection()
     {
         return m_resolution_function;
     }
@@ -55,7 +55,7 @@ private:
     AxisProperty m_phi_axis;
     AxisProperty m_alpha_axis;
 
-    PolyItem<ResolutionFunctionItemCatalog> m_resolution_function;
+    PolyItem<ResolutionFunctionCatalog> m_resolution_function;
 
     std::unique_ptr<MasksSet> m_masks;
     std::unique_ptr<MasksSet> m_prjns; //!< projections
diff --git a/GUI/Model/Detector/ResolutionFunctionItemCatalog.cpp b/GUI/Model/Detector/ResolutionFunctionCatalog.cpp
similarity index 70%
rename from GUI/Model/Detector/ResolutionFunctionItemCatalog.cpp
rename to GUI/Model/Detector/ResolutionFunctionCatalog.cpp
index 7d029de828687cfde2a242d1efb527352c260712..ce9dd6c370cb0f63c1904b530256c0480a506365 100644
--- a/GUI/Model/Detector/ResolutionFunctionItemCatalog.cpp
+++ b/GUI/Model/Detector/ResolutionFunctionCatalog.cpp
@@ -2,8 +2,8 @@
 //
 //  BornAgain: simulate and fit reflection and scattering
 //
 //! @file      GUI/Model/Detector/ResolutionFunctionItemCatalog.cpp
 //! @brief     Implements class ResolutionFunctionItemCatalog.
 //!
 //! @homepage  http://www.bornagainproject.org
 //! @license   GNU General Public License v3 or higher (see COPYING)
@@ -12,11 +12,11 @@
 //
 //  ************************************************************************************************
 
-#include "GUI/Model/Detector/ResolutionFunctionItemCatalog.h"
+#include "GUI/Model/Detector/ResolutionFunctionCatalog.h"
 #include "Base/Util/Assert.h"
 #include "GUI/Model/Detector/ResolutionFunctionItems.h"
 
-ResolutionFunctionItem* ResolutionFunctionItemCatalog::create(Type type)
+ResolutionFunctionItem* ResolutionFunctionCatalog::create(Type type)
 {
     switch (type) {
     case Type::None:
@@ -27,12 +27,12 @@ ResolutionFunctionItem* ResolutionFunctionItemCatalog::create(Type type)
     ASSERT_NEVER;
 }
 
-QVector<ResolutionFunctionItemCatalog::Type> ResolutionFunctionItemCatalog::types()
+QVector<ResolutionFunctionCatalog::Type> ResolutionFunctionCatalog::types()
 {
     return {Type::None, Type::Gaussian};
 }
 
-UiInfo ResolutionFunctionItemCatalog::uiInfo(Type type)
+UiInfo ResolutionFunctionCatalog::uiInfo(Type type)
 {
     switch (type) {
     case Type::None:
@@ -43,8 +43,7 @@ UiInfo ResolutionFunctionItemCatalog::uiInfo(Type type)
     ASSERT_NEVER;
 }
 
-ResolutionFunctionItemCatalog::Type
-ResolutionFunctionItemCatalog::type(const ResolutionFunctionItem* item)
+ResolutionFunctionCatalog::Type ResolutionFunctionCatalog::type(const ResolutionFunctionItem* item)
 {
     if (dynamic_cast<const ResolutionFunctionNoneItem*>(item))
         return Type::None;
@@ -2,8 +2,8 @@
 //  BornAgain: simulate and fit reflection and scattering
 //
-//! @file      GUI/Model/Detector/ResolutionFunctionItemCatalog.cpp
-//! @brief     Implements class ResolutionFunctionItemCatalog.
+//! @file      GUI/Model/Detector/ResolutionFunctionCatalog.cpp
+//! @brief     Implements class ResolutionFunctionCatalog.
 //!
 //! @homepage  http://www.bornagainproject.org
diff --git a/GUI/Model/Detector/ResolutionFunctionItemCatalog.h b/GUI/Model/Detector/ResolutionFunctionCatalog.h
similarity index 75%
rename from GUI/Model/Detector/ResolutionFunctionItemCatalog.h
rename to GUI/Model/Detector/ResolutionFunctionCatalog.h
index bac6136d5ede2de5bde1aa3dff4d9572e0d0b78c..459ec7214abab1bacd62f0fa9402c8e29fdc4cde 100644
--- a/GUI/Model/Detector/ResolutionFunctionItemCatalog.h
+++ b/GUI/Model/Detector/ResolutionFunctionCatalog.h
@@ -2,8 +2,8 @@
 //
 //  BornAgain: simulate and fit reflection and scattering
 //
 //! @file      GUI/Model/Detector/ResolutionFunctionItemCatalog.h
 //! @brief     Defines class ResolutionFunctionItemCatalog.
 //!
 //! @homepage  http://www.bornagainproject.org
 //! @license   GNU General Public License v3 or higher (see COPYING)
@@ -12,15 +12,15 @@
 //
 //  ************************************************************************************************
 
-#ifndef BORNAGAIN_GUI_MODEL_DETECTOR_RESOLUTIONFUNCTIONITEMCATALOG_H
-#define BORNAGAIN_GUI_MODEL_DETECTOR_RESOLUTIONFUNCTIONITEMCATALOG_H
+#ifndef BORNAGAIN_GUI_MODEL_DETECTOR_RESOLUTIONFUNCTIONCATALOG_H
+#define BORNAGAIN_GUI_MODEL_DETECTOR_RESOLUTIONFUNCTIONCATALOG_H
 
 #include "GUI/Model/Type/UiInfo.h"
 #include <QVector>
 
 class ResolutionFunctionItem;
 
-class ResolutionFunctionItemCatalog {
+class ResolutionFunctionCatalog {
 public:
     // used in PolyItem<Catalog>
     using BaseType = ResolutionFunctionItem;
@@ -41,4 +41,4 @@ public:
     static Type type(const ResolutionFunctionItem* item);
 };
 
-#endif // BORNAGAIN_GUI_MODEL_DETECTOR_RESOLUTIONFUNCTIONITEMCATALOG_H
+#endif // BORNAGAIN_GUI_MODEL_DETECTOR_RESOLUTIONFUNCTIONCATALOG_H
@@ -2,8 +2,8 @@
 //  BornAgain: simulate and fit reflection and scattering
 //
-//! @file      GUI/Model/Detector/ResolutionFunctionItemCatalog.h
-//! @brief     Defines class ResolutionFunctionItemCatalog.
+//! @file      GUI/Model/Detector/ResolutionFunctionCatalog.h
+//! @brief     Defines class ResolutionFunctionCatalog.
 //!
 //! @homepage  http://www.bornagainproject.org